<?php
/*
Plugin Name: Open Content Everyware
Description: Open Content Everyware - Publish everything, everywhere. Let the reader choose.
Version: 1.2.4
Author: Infomaker Scandinavia AB
Author URI: http://www.infomaker.se
 */

/*
 * The first thing we need to do is to make sure the Everyware Plugin is loaded first
 */
function everyware_plugin_first() {
	// ensure path to this file is via main wp plugin path
	$wp_path_to_this_file = preg_replace( '/(.*)plugins\/(.*)$/', WP_PLUGIN_DIR . "/$2", __FILE__ );
	$this_plugin          = plugin_basename( trim( $wp_path_to_this_file ) );
	$active_plugins       = get_option( 'active_plugins' );
	$this_plugin_key      = array_search( $this_plugin, $active_plugins );
	if ( $this_plugin_key ) { // if it's 0 it's the first plugin already, no need to continue
		array_splice( $active_plugins, $this_plugin_key, 1 );
		array_unshift( $active_plugins, $this_plugin );
		update_option( 'active_plugins', $active_plugins );
	}
}
add_action( "activated_plugin", "everyware_plugin_first" );

define( 'EVERY_VERSION', '1.2.4' );
define( 'EVERY_UPDATE_PATH', 'http://oc.westcoastnews.se/oc-every-wp-plugin/update.php' );
define( 'EVERY_BASE', plugin_dir_url(__FILE__) );
define( 'EVERY_DIR_PATH', plugin_dir_path( __FILE__) );

global $use_oc_cache;
$use_oc_cache = TRUE;

// Setup languages
load_plugin_textdomain( 'every', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

//Everyfy Admin/Login page
require_once dirname( __FILE__ ) . '/admin-style/admin-style.php';

//Include OC Objects
require_once dirname( __FILE__ ) . '/oc_objects/oc_article_custom_post_factory.php';
require_once dirname( __FILE__ ) . '/oc_objects/oc_ad.php';
require_once dirname( __FILE__ ) . '/oc_objects/oc_article.php';
require_once dirname( __FILE__ ) . '/oc_objects/oc_image.php';
require_once dirname( __FILE__ ) . '/oc_objects/oc_page.php';
require_once dirname( __FILE__ ) . '/oc_objects/oc_objects_collection.php';

//Include utilities and helpers
require_once dirname( __FILE__ ) . '/includes/increase_wp_security.php';
require_once dirname( __FILE__ ) . '/includes/oc_api.php';
require_once dirname( __FILE__ ) . '/includes/custom_ajax_handler.php';
require_once dirname( __FILE__ ) . '/includes/custom_oc_post_type.php';
require_once dirname( __FILE__ ) . '/includes/wp_auto_update.php';
require_once dirname( __FILE__ ) . '/includes/env_settings.php';
require_once dirname( __FILE__ ) . '/widgets/oc_widget_base.php';

if( !class_exists('OcUtilities') ){
	require_once dirname( __FILE__ ) . '/includes/oc_utilities.php';
}

require_once dirname( __FILE__ ) . '/includes/oc_cachehelper.php';
require_once dirname( __FILE__ ) . '/includes/open_content.php';
require_once dirname( __FILE__ ) . '/includes/custom_widget_handler.php';
require_once dirname( __FILE__ ) . '/includes/oc_connection.php';
require_once dirname( __FILE__ ) . '/includes/wp_extension.php';
require_once dirname( __FILE__ ) . '/includes/oc_notifier.php';
require_once dirname( __FILE__ ) . '/includes/property_map.php';
require_once dirname( __FILE__ ) . '/includes/oc_notifier_stats.php';
require_once dirname( __FILE__ ) . '/includes/every_stats.php';

require_once dirname( __FILE__ ) . '/includes/oc_meta_writer.php';
require_once dirname( __FILE__ ) . '/includes/article_events.php';
require_once dirname( __FILE__ ) . '/includes/dashboard.php';

new IncreaseWpSecurity();

//Create our custom post type (article)
new CustomOcPostType( __FILE__ );
new EveryArticleEvents( __FILE__ );

//Custom widget handler will sanitize/restore default WP-widgets when plugin is activated/deactivated
new CustomWidgetHandler( __FILE__ );
new WpExtension( __FILE__ );
new EveryStats( __FILE__ );

//Add menu to admin
if ( is_admin() ) {
//	$oc = new OpenContent( __FILE__ );
    $oc = OpenContent::getInstance();
    $oc->oc_single_hook_init(__FILE__);

	if( $oc->getLogCacheEvents() === true || $oc->getLogCacheEvents() === 'true'){
		new OcNotifierStats();
	}

	new CustomAjaxHandler();
	new PropertyMap( __FILE__ );

	new EnvSettings( __FILE__ );
	new Everyware_Dashboard();
}

// include widgets
require_once dirname( __FILE__ ) . '/widgets/oc_objects.php';
require_once dirname( __FILE__ ) . '/widgets/every_most_read_widget.php';
require_once dirname( __FILE__ ) . '/widgets/board_render_widget.php';

/*
 * Function to enable automatic updating of the EveryWare plugin
 * This functions makes sure that plugin updates will be available and presented on the Admin page of WordPress
 */
function activate_update_plugin() {
	$plugin_slug = plugin_basename( __FILE__ );
	new wp_auto_update ( EVERY_VERSION, EVERY_UPDATE_PATH, $plugin_slug );
}

add_action( 'init', 'activate_update_plugin' );

//Post Flush
add_action( 'before_delete_post', 'every_postcache_flush' );

/**
 * Function to remove an articles cache on deletion
 * @param $post_id
 */
function every_postcache_flush( $post_id ) {
    $uuid = get_post_meta($post_id, 'oc_uuid', true);

    if( !empty( $uuid )  ) {
        delete_transient( "pe_{$uuid}" );
        delete_transient( "the_post_{$uuid}" );
	    delete_transient( "the_post_id_{$uuid}" );
    }
}