<?php

include_once dirname( __FILE__ ) . '/open_content.php';
include_once dirname( __FILE__ ) . '/oc_connection.php';

class OC_Imengine {

	private $_oc;
	private $_oc_connection;
	private $_imengine;

	private $_im_adapter;
	private $_st_adapter;
	private $_quality;

	public function __construct( $quality = 60 ) {

        $this->_oc = OpenContent::getInstance();
		$this->_oc_connection = new OcConnection( $this->_oc );
		$this->_quality       = $quality;
		
		if ( class_exists( "Imagick" ) ) {
			$this->_im_adapter = new IM_Adapted();
		} else {
			$this->_im_adapter = new GD_Adapter();
		}

        if($this->_oc->getUseImengine() == "s3") {
            $this->_st_adapter = new S3_Adapter( $this->_oc->getS3AccessKey() , $this->_oc->getS3SecretKey(), $this->_oc->getS3Bucket() );
        } elseif($this->_oc->getUseImengine() == "file") {
            $this->_st_adapter = new Filestorage_Adapter( $this->_oc->getStoragePath() );
        } else {
            $this->_st_adapter = new Voidstorage_Adapter();
        }
	}


    /**
     * Creates and return a new Imengine object
     * @param $uuid
     * @param $image_url
     * @param $format
     * @return Imengine
     */
    public function image( $uuid, $image_url, $format ) {
		return new Imengine(
			$image_url,
			$this->_im_adapter,
			$this->_st_adapter,
			$this->_get_image_data( $uuid, "preview" ),
			$this->_quality,
            $format
		);
	}

    /**
     * Creates and return a new Imengine object for external image source
     * @param $image_url
     * @param $format
     * @return Imengine
     */
    public function external_image ($image_url, $format) {
        try {
            return new Imengine(
                $image_url,
                $this->_im_adapter,
                $this->_st_adapter,
                $this->_get_imgsrc_data( urldecode($image_url) ),
                $this->_quality,
                $format
            );

        } catch (Exception $e) {

        }
    }

	public function set_storage_adapter( $st_adapter ) {
		$this->_st_adapter = $st_adapter;
	}

	private function _get_image_data( $uuid, $type ) {
		return $this->_oc_connection->get_image( $uuid, $type, false );
	}


    /**
     * Get image data from external source
     * Returns image data if success or 404 if not found.
     *
     * @param $imgsrc
     * @return null|string
     */
    protected function _get_imgsrc_data($imgsrc) {

        $api_response = wp_remote_get( $imgsrc, [] );

        $data = [];
        do_action('analyzer_add_data', ['name' => 'ImEngine from Plugin', 'debug' => debug_backtrace(DEBUG_BACKTRACE_PROVIDE_OBJECT, 1)], 'IMENGINE');

        if ( ! is_wp_error( $api_response ) ) {
            $http_status = wp_remote_retrieve_response_code( $api_response );
            if ( $http_status == "200" ) {
                return wp_remote_retrieve_body($api_response);
            } elseif ( $http_status == '401' ) {
                return '401';
            } else if($http_status == '404') {
                return '404';
            } else {
                return null;
            }
        }
        return null;
    }

}
